
package com.br.fechadura.mobile.ui.screens.usuario

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.Person
import androidx.compose.material.icons.filled.Search
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.viewModel.UsuariosViewModel
import com.br.vini.compose.api.ApiState
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil.compose.rememberAsyncImagePainter
import com.br.fechadura.mobile.ui.screens.FailScreen
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.ui.theme.Branco
import com.br.fechadura.mobile.ui.theme.FundoFechaduraColor

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun UsuarioScreen(
    navController: NavController
) {
    var text by remember { mutableStateOf("") }

    val usuarioViewModel: UsuariosViewModel = viewModel()
    val usuariosState by usuarioViewModel.allUsuarios

    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Usuários",
                searchText = text,
                onSearchChange = { text = it },
                showSearchIcon = false,
                showBackButton = false
            )
        },
        floatingActionButton = {
            FloatingActionButton(
                onClick = { navController.navigate("cadastrar-usuario") },
                containerColor = FechaduraColor
            ) {
                Icon(Icons.Default.Add, contentDescription = "Add", tint = Branco)
            }
        }
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding)
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
            ) {
                when (usuariosState) {
                    is ApiState.Created -> {}
                    is ApiState.Loading -> {
                        if (usuariosState.data?.data.isNullOrEmpty()) {
                            LoadingScreen()
                        }
                    }

                    is ApiState.Success -> {
                        usuariosState.data?.let { responseData ->
                            if (responseData.data.isNullOrEmpty()) {
                                Text(text = "Nenhum usuário")
                            } else {
                                LazyColumn(
                                    modifier = Modifier
                                        .fillMaxSize()
                                        .background(Color.White)
                                ) {
                                    item {
                                            SearchBar(
                                                modifier = Modifier
                                                    .padding(10.dp)
                                                    .fillMaxWidth(),
                                                query = text,
                                                onQueryChange = {
                                                    text = it
                                                },
                                                onSearch = {},
                                                active = false,
                                                onActiveChange = {},
                                                colors = SearchBarDefaults.colors(
                                                    containerColor = FundoFechaduraColor
                                                ),
                                                placeholder = { Text("Buscar usuário") },
                                                leadingIcon = {
                                                    Icon(
                                                        Icons.Default.Search,
                                                        contentDescription = null
                                                    )
                                                },

                                                ) {
                                            }
                                    }
                                    items(
                                        items = responseData.data.filter {
                                            it.nome.contains(text, ignoreCase = true)
                                        },
                                        key = { usuario -> usuario._id }
                                    ) { usuario ->
                                            Row(
                                                horizontalArrangement = Arrangement.SpaceBetween,
                                                modifier = Modifier
                                                    .fillMaxWidth()
                                                    .weight(1f)
                                                    .clickable {
                                                        navController.navigate("visualizar-usuario/${usuario._id}")
                                                    }
                                                    .padding(20.dp),
                                                verticalAlignment = Alignment.CenterVertically
                                            ) {
                                                Row(
                                                    verticalAlignment = Alignment.CenterVertically
                                                ) {
                                                    if (usuario.link_foto.isNullOrEmpty()) {
                                                        // Mostrar ícone padrão se não houver imagem
                                                        Box(
                                                            modifier = Modifier
                                                                .size(40.dp)
                                                                .clip(CircleShape)
                                                                .background(Color.White),
                                                            contentAlignment = Alignment.Center,
                                                        ) {
                                                            Icon(
                                                                imageVector = Icons.Default.Person,
                                                                contentDescription = "User Avatar",
                                                                modifier = Modifier.size(30.dp),
                                                                tint = Color.Black
                                                            )
                                                        }
                                                    } else {
                                                        // Carregar a imagem do usuário
                                                        Image(
                                                            painter = rememberAsyncImagePainter(usuario.link_foto),
                                                            contentDescription = "Avatar do usuário",
                                                            modifier = Modifier
                                                                .size(40.dp)
                                                                .clip(CircleShape)
                                                                .background(Color.Gray),
                                                            contentScale = ContentScale.Crop
                                                        )
                                                    }

                                                    Text(
                                                        text = if (usuario.nome.length > 25) "${usuario.nome.take(25)}..." else usuario.nome,
                                                        color = Color.Black,
                                                        modifier = Modifier.padding(start = 10.dp)
                                                    )
                                            }
                                                    Text(
                                                        text = if (usuario.ativo) "Ativo" else "Inativo",
                                                        fontSize = 12.sp,
                                                        color = if (usuario.ativo) FechaduraColor else Color.Red
                                                    )

                                            }
                                    }
                                }
                            }
                        }
                    }

                    is ApiState.Error -> {
                        usuariosState.message?.let { message ->
                            FailScreen(message)
                        }
                    }
                }
            }
        }
    }

    // Carregamento inicial
    LaunchedEffect(Unit) {
        usuarioViewModel.getAllUsuarios()
    }
}
